==> org.eclipse.swt.gtk.linux.x86.source_3.106.2.v20171129-0543.jar: org/eclipse/swt/internal/gtk/GdkEventMotion.java <==
/*******************************************************************************
 * Copyright (c) 2000, 2012 IBM Corporation and others. All rights reserved.
 * The contents of this file are made available under the terms
 * of the GNU Lesser General Public License (LGPL) Version 2.1 that
 * accompanies this distribution (lgpl-v21.txt).  The LGPL is also
 * available at http://www.gnu.org/licenses/lgpl.html.  If the version
 * of the LGPL at http://www.gnu.org is different to the version of
 * the LGPL accompanying this distribution and there is any conflict
 * between the two license versions, the terms of the LGPL accompanying
 * this distribution shall govern.
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.swt.internal.gtk;


public class GdkEventMotion extends GdkEvent {
	/** @field cast=(GdkWindow *) */
	public int /*long*/ window;
	/** @field cast=(gint8) */
	public byte send_event;
	/** @field cast=(guint32) */
	public int time;
	/** @field cast=(gdouble) */
	public double x;
	/** @field cast=(gdouble) */
	public double y;
	/** @field cast=(gdouble *) */
	public int /*long*/ axes;
	/** @field cast=(guint) */
	public int state;
	/** @field cast=(gint16) */
	public short is_hint;
	/** @field cast=(GdkDevice *) */
	public int /*long*/ device;
	/** @field cast=(gdouble) */
	public double x_root;
	/** @field cast=(gdouble) */
	public double y_root;
	public static final int sizeof = OS.GdkEventMotion_sizeof();
}

==> org.eclipse.swt.gtk.linux.x86.source_3.108.0.v20180904-1901.jar: org/eclipse/swt/internal/gtk/GdkEventMotion.java <==
/*******************************************************************************
 * Copyright (c) 2000, 2012 IBM Corporation and others. All rights reserved.
 * The contents of this file are made available under the terms
 * of the GNU Lesser General Public License (LGPL) Version 2.1 that
 * accompanies this distribution (lgpl-v21.txt).  The LGPL is also
 * available at http://www.gnu.org/licenses/lgpl.html.  If the version
 * of the LGPL at http://www.gnu.org is different to the version of
 * the LGPL accompanying this distribution and there is any conflict
 * between the two license versions, the terms of the LGPL accompanying
 * this distribution shall govern.
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.swt.internal.gtk;


public class GdkEventMotion extends GdkEvent {
	/** @field cast=(GdkWindow *) */
	public int /*long*/ window;
	/** @field cast=(gint8) */
	public byte send_event;
	/** @field cast=(guint32) */
	public int time;
	/** @field cast=(gdouble) */
	public double x;
	/** @field cast=(gdouble) */
	public double y;
	/** @field cast=(gdouble *) */
	public int /*long*/ axes;
	/** @field cast=(guint) */
	public int state;
	/** @field cast=(gint16) */
	public short is_hint;
	/** @field cast=(GdkDevice *) */
	public int /*long*/ device;
	/** @field cast=(gdouble) */
	public double x_root;
	/** @field cast=(gdouble) */
	public double y_root;
	public static final int sizeof = GDK.GdkEventMotion_sizeof();
}
